@@ -72,24 +72,35 @@ namespace Sass {
 
       // now create the code trace (ToDo: maybe have util functions?)
       if (e.pstate.line != std::string::npos && e.pstate.column != std::string::npos) {
-        size_t line = e.pstate.line;
+        size_t lines = e.pstate.line;
         const char* line_beg = e.pstate.src;
-        while (line_beg && *line_beg && line) {
-          if (*line_beg == '\n') --line;
-          ++line_beg;
+        // scan through src until target line
+        // move line_beg pointer to line start
+        while (line_beg && *line_beg && lines != 0) {
+          if (*line_beg == '\n') --lines;
+          utf8::unchecked::next(line_beg); 
         }
         const char* line_end = line_beg;
+        // move line_end before next newline character
         while (line_end && *line_end && *line_end != '\n') {
           if (*line_end == '\n') break;
           if (*line_end == '\r') break;
-          line_end++;
+          utf8::unchecked::next(line_end); 
         }
-        size_t max_left = 42; size_t max_right = 78;
-        size_t move_in = e.pstate.column > max_left ? e.pstate.column - max_left : 0;
-        size_t shorten = (line_end - line_beg) - move_in > max_right ?
-          (line_end - line_beg) - move_in - max_right : 0;
-        msg_stream << ">> " << std::string(line_beg + move_in, line_end - shorten) << "\n";
-        msg_stream << "   " << std::string(e.pstate.column - move_in, '-') << "^\n";
+        if (line_end && *line_end != 0) ++ line_end;
+        size_t line_len = line_end - line_beg;
+        size_t move_in = 0; size_t shorten = 0;
+        size_t left_chars = 42; size_t max_chars = 76;
+        // reported excerpt should not exceed `max_chars` chars
+        if (e.pstate.column > line_len) left_chars = e.pstate.column;
+        if (e.pstate.column > left_chars) move_in = e.pstate.column - left_chars;
+        if (line_len > max_chars + move_in) shorten = line_len - move_in - max_chars;
+        utf8::advance(line_beg, move_in, line_end);
+        utf8::retreat(line_end, shorten, line_beg);
+        std::string sanitized; std::string marker(e.pstate.column - move_in, '-');
+        utf8::replace_invalid(line_beg, line_end, std::back_inserter(sanitized));
+        msg_stream << ">> " << sanitized << "\n";
+        msg_stream << "   " << marker << "^\n";
       }
 
       JsonNode* json_err = json_mkobject();
@@ -523,30 +534,10 @@ extern "C" {
   static void sass_clear_options (struct Sass_Options* options)
   {
     if (options == 0) return;
-    // Deallocate custom functions
-    if (options->c_functions) {
-      Sass_Function_List this_func_data = options->c_functions;
-      while (this_func_data && *this_func_data) {
-        free(*this_func_data);
-        ++this_func_data;
-      }
-    }
-    // Deallocate custom headers
-    if (options->c_headers) {
-      Sass_Importer_List this_head_data = options->c_headers;
-      while (this_head_data && *this_head_data) {
-        free(*this_head_data);
-        ++this_head_data;
-      }
-    }
-    // Deallocate custom importers
-    if (options->c_importers) {
-      Sass_Importer_List this_imp_data = options->c_importers;
-      while (this_imp_data && *this_imp_data) {
-        free(*this_imp_data);
-        ++this_imp_data;
-      }
-    }
+    // Deallocate custom functions, headers and importes
+    sass_delete_function_list(options->c_functions);
+    sass_delete_importer_list(options->c_importers);
+    sass_delete_importer_list(options->c_headers);
     // Deallocate inc paths
     if (options->plugin_paths) {
       struct string_list* cur;
@@ -578,11 +569,6 @@ extern "C" {
     free(options->include_path);
     free(options->source_map_file);
     free(options->source_map_root);
-    // Free custom functions
-    free(options->c_functions);
-    // Free custom importers
-    free(options->c_importers);
-    free(options->c_headers);
     // Reset our pointers
     options->input_path = 0;
     options->output_path = 0;
