@@ -22,7 +22,9 @@ bool get_image_size(const char *fn, size_t *x,size_t *y)
   // reading PNG dimensions requires the first 24 bytes of the file
   // reading JPEG dimensions requires scanning through jpeg chunks
   // In all formats, the file is at least 24 bytes big, so we'll read that always
-  unsigned char buf[24]; fread(buf,1,24,f);
+  unsigned char buf[24];
+  if (fread(buf,1,24,f) != 24)
+    return false;
 
   // For JPEGs, we need to read the first 12 bytes of each chunk.
   // We'll read those 12 bytes at buf+2...buf+14, i.e. overwriting the existing buf.
@@ -32,7 +34,9 @@ bool get_image_size(const char *fn, size_t *x,size_t *y)
     { if (buf[3]==0xC0 || buf[3]==0xC1 || buf[3]==0xC2 || buf[3]==0xC3 || buf[3]==0xC9 || buf[3]==0xCA || buf[3]==0xCB) break;
       pos += 2+(buf[4]<<8)+buf[5];
       if (pos+12>len) break;
-      fseek(f,pos,SEEK_SET); fread(buf+2,1,12,f);
+      fseek(f,pos,SEEK_SET);
+      if (fread(buf+2,1,12,f) != 12)
+        return false;
     }
   }
 
